==> dl.php?src=linea21_1_7.zip: linea21/languages/en/lang_sdi.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['sdi']['name']="indicator";
$lang['sdi']['confirm_add'] = "Indicator successfully added";
$lang['sdi']['confirm_mod'] = "Indicator successfully updated";
$lang['sdi']['confirm_clone'] = "Indicator successfully cloned";
$lang['sdi']['confirm_sup'] ="Indicator successfully deleted";



$lang['sdi']['p_name']="provider";
$lang['sdi']['p_confirm_mod'] = "Provider successfully updated";
$lang['sdi']['p_confirm_sup'] ="Provider successfully deleted";


$lang['sdi']['r_name']="rules";
$lang['sdi']['r_confirm_mod'] = "Rules successfully updated";
$lang['sdi']['r_confirm_sup'] ="Rules successfully deleted";


$lang['sdi']['e_name']="assessment";
$lang['sdi']['e_confirm_mod'] = "Assessment successfully updated";
$lang['sdi']['e_confirm_sup'] ="Assessment successfully deleted";


/*	nommage rubrique module
 *  	*/
$lang['sdi']['add']= "Add a new ".$lang['sdi']['name'];


$lang['sdi']['mod']= "Edit global informations";
$lang['sdi']['clone']= "Clone current indicator";
$lang['sdi']['sup']= "Delete the ".$lang['sdi']['name'];


$lang['sdi']['mod_e']= "Edit ".$lang['sdi']['e_name'];
$lang['sdi']['sup_e']= "Delete the ".$lang['sdi']['e_name'];


$lang['sdi']['mod_p']= "Edit ".$lang['sdi']['p_name'];
$lang['sdi']['sup_p']= "Delete the ".$lang['sdi']['p_name'];


$lang['sdi']['mod_r']= "Edit ".$lang['sdi']['r_name'];
$lang['sdi']['sup_r']= "Delete the ".$lang['sdi']['r_name'];


$lang['sdi']['det']= ucfirst($lang['sdi']['name']) . " details";
$lang['sdi']['list']= "View indicators";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['sdi']['add_title1']="Add global informations about the new ".$lang['sdi']['name'];
$lang['sdi']['add_title2']="Add assessment's criteria about the new ".$lang['sdi']['name'];
$lang['sdi']['add_title3']="Add provider's contact details about the new ".$lang['sdi']['name'];
$lang['sdi']['add_title4']="Add rules about the new ".$lang['sdi']['name'];


$lang['sdi']['mod_title']="Edit global informations about :";
$lang['sdi']['mod_title2']="Edit assessment's criteria about :";
$lang['sdi']['mod_title3']="Edit provider's contact details about :";
$lang['sdi']['mod_title4']="Edit rules about :";


$lang['sdi']['recap_commment']="no comment";
$lang['sdi']['confirmation']="confirm subscription";




/*	nommage étapes add
 *  	*/


$lang['sdi']['add_step1']="global informations";
$lang['sdi']['add_step2']="assessment";
$lang['sdi']['add_step3']="provider";
$lang['sdi']['add_step4']="rules";
$lang['sdi']['btn_step1']="step 2";
$lang['sdi']['btn_step2']="step 3";
$lang['sdi']['btn_step3']="step 4";
$lang['sdi']['btn_fin']="end now!";


/*	nommage rubrique sup
 *  	*/
$lang['sdi']['sup_sdi_warning']="Are you sure you want to delete this ".$lang['sdi']['name']." ?";
$lang['sdi']['sup_sdi_warning2']="The removal of this indicator induced deletion of his provider, rules, its values and its assessment criteria.";
$lang['sdi']['sup_sdi_warning3']="Caution, the theme associated with this indicator will be empty after deletion";
/*	nommage élément rubrique
 *  	*/

$lang['sdi']['name2']="name";
$lang['sdi']['type']="indicator type";
$lang['sdi']['dashboard_viz']="vizualisation type - dashboard";
$lang['sdi']['detail_viz']="vizualisation type - detail";
$lang['sdi']['description']="description";
$lang['sdi']['comment']="comments";
$lang['sdi']['theme']="destination theme";
$lang['sdi']['range']="rank";
$lang['sdi']['goal']="objectives (goals)";
$lang['sdi']['consulting']="tips for improvement";
$lang['sdi']['attached_to_dashboard']="Attached to dashboard";
$lang['sdi']['not_attached_to_dashboard']="Not attached to dashboard";
$lang['sdi']['info_mesure']="measures informations";
$lang['sdi']['unit']="unit of measurement";
$lang['sdi']['max_value']="maximum";
$lang['sdi']['min_value']="minimum";
$lang['sdi']['initial_threshold_value']="initial threshold";
$lang['sdi']['threshold_value']="threshold";
$lang['sdi']['threshold_relative']="relative behavior to threshold";
$lang['sdi']['threshold_relative_comment']="Check this box if the goal is reached for a value superior to the threshold.";
$lang['sdi']['threshold_relative_Y']="the goal is achieved if the value exceeds the threshold.";
$lang['sdi']['threshold_relative_N']="the goal is not achieved if the value exceeds the threshold.";
$lang['sdi']['frequency']="collect frequency";


$lang['sdi']['e_title']="Criteria for evaluating data";
$lang['sdi']['e_scale_compare']="comparability";
$lang['sdi']['e_fiability']="fiability";
$lang['sdi']['e_accessibility']="accessibility";
$lang['sdi']['e_lisibility']="readibility";
$lang['sdi']['e_relevance']="relevance";
$lang['sdi']['e_global_performance']="overall performance";


$lang['sdi']['p_title']="data provider";
$lang['sdi']['p_name']="name";
$lang['sdi']['p_service']="service";
$lang['sdi']['p_description']="description";
$lang['sdi']['p_incharge']="incharge";
$lang['sdi']['p_address']="address";
$lang['sdi']['p_phone']="phone number";
$lang['sdi']['p_fax']="fax number";
$lang['sdi']['p_email']="email";


$lang['sdi']['r_title']="rules reference";
$lang['sdi']['r_body']="regulation text";
$lang['sdi']['r_referer_uri']="link (url)";
$lang['sdi']['r_mask_uri']="link (text to display)";

/** select-box option and values (keys) */
$lang['sdi']['select_type']['quantitative']='quantitative';
$lang['sdi']['select_type']['qualitative']='qualitative';
$lang['sdi']['select_dashboard_viz']['raw']='raw value';
$lang['sdi']['select_dashboard_viz']['gauge']='gauge';
$lang['sdi']['select_detail_viz']['column']='colmun';
$lang['sdi']['select_dashboard_viz']['sparkline']='sparkline';
$lang['sdi']['select_detail_viz']['line']='line';
$lang['sdi']['select_detail_viz']['area']='area';

/*	nommage quickbox
 *  	*/
$lang['sdi']['qb_add_title']=" latest additions";
$lang['sdi']['qb_mod_title']=" latest modifications";


/*	divers
 *  	*/
$lang['sdi']['select_choice']="-- Choose in this list --";
$lang['sdi']['facultatif']="Optional";
$lang['sdi']['theme_filter']="Display by theme";
$lang['sdi']['notheme']="No theme";
$lang['sdi']['aff_sdi_e']="Display assessment criteria";
$lang['sdi']['modify_sdi_e']="Update assessment criteria";

$lang['sdi']['aff_sdi_r']="Display rules";
$lang['sdi']['modify_sdi_r']="Update rules";
$lang['sdi']['aff_sdi_p']="Display provider informations";
$lang['sdi']['modify_sdi_p']="Update provider informations";
$lang['sdi']['noresultp']="Add a new provider by clicking on the add icon linked in";
$lang['sdi']['noresultr']="Add a new rule by clicking on the add icon linked in";
$lang['sdi']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['sdi']['clone_suffix']= "clone";

/*	messages
 *  	*/


$lang['sdi']['object_notname']="Name is required.";
$lang['sdi']['object_notdescription']="Description is required.";
$lang['sdi']['object_nottheme']="Theme is required.";
$lang['sdi']['object_notrange']="Rank is required.";
$lang['sdi']['object_notunit']="Unit is required.";
$lang['sdi']['object_notmax_value']="Maximal value must be numerical.";
$lang['sdi']['object_notmin_value']="Minimal value must be numerical.";
$lang['sdi']['object_notthreshold_value']="Threshold value must be numerical.";
$lang['sdi']['object_notfrequency']="Frequency value must be numerical.";
$lang['sdi']['server_noresponse']='Wrong url : no response from the server, please check your syntax';




$lang['sdi']['object_note_scale_compare']="Comparability must be a numerical value.";
$lang['sdi']['object_note_fiability']="Fiability must be a numerical value.";
$lang['sdi']['object_note_accessibility']="Accessibility must be a numerical value.";
$lang['sdi']['object_note_lisibility']="Readability must be a numerical value.";
$lang['sdi']['object_note_relevance']="Relevance must be a numerical value.";
$lang['sdi']['object_note_global_performance']="Overall performance must be a numerical value.";




$lang['sdi']['object_notp_name']="Provider name is required";
$lang['sdi']['object_notp_address']="Address is required";
$lang['sdi']['object_notp_phone']="Phone number is not valid";
$lang['sdi']['object_notp_fax']="Fax number is not valid";
$lang['sdi']['object_notp_mail']="Email is not valid";


$lang['sdi']['object_notr_title']="Rules reference is required";
$lang['sdi']['object_notr_body']="Regulation text is required";


/*	rubrique d'aide
 *  	*/
$lang['sdi']['help_add1']="To add a new indicator, please insert the required informations in the form above";
$lang['sdi']['help_add2']="Four steps are required to add an indicator : global informations -> assessment -> provider -> rules";
$lang['sdi']['help_add3']="After submitting the form, check your data in the summary";
$lang['sdi']['help_add4']='After checking summary, click the \'review settings\' button to make new changes';
$lang['sdi']['help_add5']="Click the '".$lang['sdi']['btn_fin']."' button to directly access the summary and quickly add a record";
$lang['sdi']['help_add6']="Fields marked with an asterisk are required";


$lang['sdi']['help_list1']="Click on indicator titles to display more informations";
$lang['sdi']['help_list2']="Delete indicator by clicking on the delete icon linked in";
$lang['sdi']['help_list3']="Edit indicator by clicking on the edit icon linked in";
$lang['sdi']['help_list4']="To add a new indicator, please insert the required informations in the form above";
$lang['sdi']['help_list5']="To perform search on indicators only, just click the 'search' link";

$lang['sdi']['help_mod1']="To edit global informations, please insert the required informations in the form above";
$lang['sdi']['help_mod2']="After submitting the form, check your data in the summary";
$lang['sdi']['help_mod3']="After checking summary, click the \'review settings\' button to make new changes";
$lang['sdi']['help_mod4']="To edit provider informations, rules and assessment, click  the 'update informations' button  at the top of the page.";
$lang['sdi']['help_mod5']="Edit global informations by clicking on the edit icon linked in on the indicators details page.";


$lang['sdi']['help_mod_p1']="To edit provider informations, please insert the required informations in the form above";
$lang['sdi']['help_mod_e1']="To edit assessment informations, please insert the required informations in the form above";
$lang['sdi']['help_mod_r1']="To edit rules informations, please insert the required informations in the form above";


$lang['sdi']['help_det1']="Edit global informations by clicking on the edit icon linked in";
$lang['sdi']['help_det2']="Delete indicator by clicking on the delete icon linked in";
$lang['sdi']['help_det3']="Click on indicator themes to display more informations about this theme";
$lang['sdi']['help_det4']="To display provider informations, rules and assessment, click  the 'display informations' button  at the bottom of the page.";
$lang['sdi']['help_det5']="Edit information providers, rules and assessments by clicking on the edit icon linked in";


$lang['sdi']['help_sup1']="Click on validate to definitively delete indicators and associated values (providers, rules and assessment)";
$lang['sdi']['help_sup2']="A warning message will appear if the theme is empty after the indicator deletion";
?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/en/lang_sdi.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['sdi']['name']="indicator";
$lang['sdi']['confirm_add'] = "Indicator successfully added";
$lang['sdi']['confirm_mod'] = "Indicator successfully updated";
$lang['sdi']['confirm_clone'] = "Indicator successfully cloned";
$lang['sdi']['confirm_sup'] ="Indicator successfully deleted";



$lang['sdi']['p_name']="provider";
$lang['sdi']['p_confirm_mod'] = "Provider successfully updated";
$lang['sdi']['p_confirm_sup'] ="Provider successfully deleted";


$lang['sdi']['r_name']="rules";
$lang['sdi']['r_confirm_mod'] = "Rules successfully updated";
$lang['sdi']['r_confirm_sup'] ="Rules successfully deleted";


$lang['sdi']['e_name']="assessment";
$lang['sdi']['e_confirm_mod'] = "Assessment successfully updated";
$lang['sdi']['e_confirm_sup'] ="Assessment successfully deleted";


/*	nommage rubrique module
 *  	*/
$lang['sdi']['add']= "Add a new ".$lang['sdi']['name'];


$lang['sdi']['mod']= "Edit global informations";
$lang['sdi']['clone']= "Clone current indicator";
$lang['sdi']['sup']= "Delete the ".$lang['sdi']['name'];


$lang['sdi']['mod_e']= "Edit ".$lang['sdi']['e_name'];
$lang['sdi']['sup_e']= "Delete the ".$lang['sdi']['e_name'];


$lang['sdi']['mod_p']= "Edit ".$lang['sdi']['p_name'];
$lang['sdi']['sup_p']= "Delete the ".$lang['sdi']['p_name'];


$lang['sdi']['mod_r']= "Edit ".$lang['sdi']['r_name'];
$lang['sdi']['sup_r']= "Delete the ".$lang['sdi']['r_name'];


$lang['sdi']['det']= ucfirst($lang['sdi']['name']) . " details";
$lang['sdi']['list']= "View indicators";


/*	nommage rubrique add / mod /det
 *  	*/
$lang['sdi']['add_title1']="Add global informations about the new ".$lang['sdi']['name'];
$lang['sdi']['add_title2']="Add assessment's criteria about the new ".$lang['sdi']['name'];
$lang['sdi']['add_title3']="Add provider's contact details about the new ".$lang['sdi']['name'];
$lang['sdi']['add_title4']="Add rules about the new ".$lang['sdi']['name'];


$lang['sdi']['mod_title']="Edit global informations about :";
$lang['sdi']['mod_title2']="Edit assessment's criteria about :";
$lang['sdi']['mod_title3']="Edit provider's contact details about :";
$lang['sdi']['mod_title4']="Edit rules about :";


$lang['sdi']['recap_commment']="no comment";
$lang['sdi']['confirmation']="confirm subscription";




/*	nommage étapes add
 *  	*/


$lang['sdi']['add_step1']="global informations";
$lang['sdi']['add_step2']="assessment";
$lang['sdi']['add_step3']="provider";
$lang['sdi']['add_step4']="rules";
$lang['sdi']['btn_step1']="step 2";
$lang['sdi']['btn_step2']="step 3";
$lang['sdi']['btn_step3']="step 4";
$lang['sdi']['btn_fin']="end now!";


/*	nommage rubrique sup
 *  	*/
$lang['sdi']['sup_sdi_warning']="Are you sure you want to delete this ".$lang['sdi']['name']." ?";
$lang['sdi']['sup_sdi_warning2']="The removal of this indicator induced deletion of his provider, rules, its values and its assessment criteria.";
$lang['sdi']['sup_sdi_warning3']="Caution, the theme associated with this indicator will be empty after deletion";
/*	nommage élément rubrique
 *  	*/

$lang['sdi']['name2']="name";
$lang['sdi']['type']="indicator type";
$lang['sdi']['value_type']="value type";
$lang['sdi']['dashboard_viz']="vizualisation type - dashboard";
$lang['sdi']['detail_viz']="vizualisation type - detail";
$lang['sdi']['description']="description";
$lang['sdi']['comment']="comments";
$lang['sdi']['theme']="destination theme";
$lang['sdi']['sdtheme']="finality";
$lang['sdi']['range']="rank";
$lang['sdi']['goal']="objectives (goals)";
$lang['sdi']['consulting']="tips for improvement";
$lang['sdi']['attached_to_dashboard']="Attached to dashboard";
$lang['sdi']['not_attached_to_dashboard']="Not attached to dashboard";
$lang['sdi']['info_mesure']="measures informations";
$lang['sdi']['unit']="unit of measurement";
$lang['sdi']['max_value']="maximum";
$lang['sdi']['min_value']="minimum";
$lang['sdi']['initial_threshold_value']="initial threshold";
$lang['sdi']['threshold_value']="threshold";
$lang['sdi']['threshold_relative']="relative behavior to threshold";
$lang['sdi']['threshold_relative_comment']="Check this box if the goal is reached for a value superior to the threshold.";
$lang['sdi']['threshold_relative_Y']="the goal is achieved if the value exceeds the threshold.";
$lang['sdi']['threshold_relative_N']="the goal is not achieved if the value exceeds the threshold.";
$lang['sdi']['frequency']="collect frequency";

$lang['sdi']['bool_indicator']='Boolean indicator.';
$lang['sdi']['boolindicator_notice']='Boolean indicator. You can define a mask using the following syntax <strong>{0=no;1=yes}</strong> in the field <a href=\"%s\">comment</a>.';
$lang['sdi']['boolindicator_mask']='The following mask is defined : %s.';
$lang['sdi']['boolindicator_nomask']='No mask defined.';

$lang['sdi']['e_title']="Criteria for evaluating data";
$lang['sdi']['e_scale_compare']="comparability";
$lang['sdi']['e_fiability']="fiability";
$lang['sdi']['e_accessibility']="accessibility";
$lang['sdi']['e_lisibility']="readibility";
$lang['sdi']['e_relevance']="relevance";
$lang['sdi']['e_global_performance']="overall performance";


$lang['sdi']['p_title']="data provider";
$lang['sdi']['p_name']="name";
$lang['sdi']['p_service']="service";
$lang['sdi']['p_description']="description";
$lang['sdi']['p_incharge']="incharge";
$lang['sdi']['p_address']="address";
$lang['sdi']['p_phone']="phone number";
$lang['sdi']['p_fax']="fax number";
$lang['sdi']['p_email']="email";


$lang['sdi']['r_title']="rules reference";
$lang['sdi']['r_body']="regulation text";
$lang['sdi']['r_referer_uri']="link (url)";
$lang['sdi']['r_mask_uri']="link (text to display)";

/** select-box option and values (keys) */
$lang['sdi']['select_type']['quantitative']='quantitative';
//$lang['sdi']['select_type']['qualitative']='qualitative';
$lang['sdi']['select_type']['boolean']='boolean';
$lang['sdi']['select_value_type']['unique']='unique';
$lang['sdi']['select_value_type']['multiple']='multiple';
$lang['sdi']['select_dashboard_viz']['raw']='raw value';
$lang['sdi']['select_dashboard_viz']['gauge']='gauge';
$lang['sdi']['select_detail_viz']['column']='colmun';
$lang['sdi']['select_dashboard_viz']['sparkline']='sparkline';
$lang['sdi']['select_detail_viz']['line']='line';
$lang['sdi']['select_detail_viz']['area']='area';

/*	nommage quickbox
 *  	*/
$lang['sdi']['qb_add_title']=" latest additions";
$lang['sdi']['qb_mod_title']=" latest modifications";


/*	divers
 *  	*/
$lang['sdi']['select_choice']="-- Choose in this list --";
$lang['sdi']['facultatif']="Optional";
$lang['sdi']['theme_filter']="Display by theme";
$lang['sdi']['notheme']="No theme";
$lang['sdi']['aff_sdi_e']="Display assessment criteria";
$lang['sdi']['modify_sdi_e']="Update assessment criteria";

$lang['sdi']['aff_sdi_r']="Display rules";
$lang['sdi']['modify_sdi_r']="Update rules";
$lang['sdi']['aff_sdi_p']="Display provider informations";
$lang['sdi']['modify_sdi_p']="Update provider informations";
$lang['sdi']['noresultp']="Add a new provider by clicking on the add icon linked in";
$lang['sdi']['noresultr']="Add a new rule by clicking on the add icon linked in";
$lang['sdi']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['sdi']['clone_suffix']= "clone";
$lang['sdi']['clone_confirmation']= "Are you sure you want to clone this indicator?";

/*	messages
 *  	*/


$lang['sdi']['object_notname']="Name is required.";
$lang['sdi']['object_notdescription']="Description is required.";
$lang['sdi']['object_nottheme']="Theme is required.";
$lang['sdi']['object_notrange']="Rank is required.";
$lang['sdi']['object_notunit']="Unit is required.";
$lang['sdi']['object_notmax_value']="Maximal value must be numerical.";
$lang['sdi']['object_notmin_value']="Minimal value must be numerical.";
$lang['sdi']['object_notthreshold_value']="Threshold value must be numerical.";
$lang['sdi']['object_notfrequency']="Frequency value must be set (as numbers of days).";
$lang['sdi']['server_noresponse']='Wrong url : no response from the server, please check your syntax';




$lang['sdi']['object_note_scale_compare']="Comparability must be a numerical value.";
$lang['sdi']['object_note_fiability']="Fiability must be a numerical value.";
$lang['sdi']['object_note_accessibility']="Accessibility must be a numerical value.";
$lang['sdi']['object_note_lisibility']="Readability must be a numerical value.";
$lang['sdi']['object_note_relevance']="Relevance must be a numerical value.";
$lang['sdi']['object_note_global_performance']="Overall performance must be a numerical value.";




$lang['sdi']['object_notp_name']="Provider name is required";
$lang['sdi']['object_notp_address']="Address is required";
$lang['sdi']['object_notp_phone']="Phone number is not valid";
$lang['sdi']['object_notp_fax']="Fax number is not valid";
$lang['sdi']['object_notp_mail']="Email is not valid";


$lang['sdi']['object_notr_title']="Rules reference is required";
$lang['sdi']['object_notr_body']="Regulation text is required";


/*	rubrique d'aide
 *  	*/
$lang['sdi']['help_add1']="To add a new indicator, please insert the required informations in the form above";
$lang['sdi']['help_add2']="Four steps are required to add an indicator : global informations -> assessment -> provider -> rules";
$lang['sdi']['help_add3']="After submitting the form, check your data in the summary";
$lang['sdi']['help_add4']='After checking summary, click the \'review settings\' button to make new changes';
$lang['sdi']['help_add5']="Click the '".$lang['sdi']['btn_fin']."' button to directly access the summary and quickly add a record";
$lang['sdi']['help_add6']="Fields marked with an asterisk are required";


$lang['sdi']['help_list1']="Click on indicator titles to display more informations";
$lang['sdi']['help_list2']="Delete indicator by clicking on the delete icon linked in";
$lang['sdi']['help_list3']="Edit indicator by clicking on the edit icon linked in";
$lang['sdi']['help_list4']="To add a new indicator, please insert the required informations in the form above";
$lang['sdi']['help_list5']="To perform search on indicators only, just click the 'search' link";

$lang['sdi']['help_mod1']="To edit global informations, please insert the required informations in the form above";
$lang['sdi']['help_mod2']="After submitting the form, check your data in the summary";
$lang['sdi']['help_mod3']="After checking summary, click the \'review settings\' button to make new changes";
$lang['sdi']['help_mod4']="To edit provider informations, rules and assessment, click  the 'update informations' button  at the top of the page.";
$lang['sdi']['help_mod5']="Edit global informations by clicking on the edit icon linked in on the indicators details page.";


$lang['sdi']['help_mod_p1']="To edit provider informations, please insert the required informations in the form above";
$lang['sdi']['help_mod_e1']="To edit assessment informations, please insert the required informations in the form above";
$lang['sdi']['help_mod_r1']="To edit rules informations, please insert the required informations in the form above";


$lang['sdi']['help_det1']="Edit global informations by clicking on the edit icon linked in";
$lang['sdi']['help_det2']="Delete indicator by clicking on the delete icon linked in";
$lang['sdi']['help_det3']="Click on indicator themes to display more informations about this theme";
$lang['sdi']['help_det4']="To display provider informations, rules and assessment, click  the 'display informations' button  at the bottom of the page.";
$lang['sdi']['help_det5']="Edit information providers, rules and assessments by clicking on the edit icon linked in";


$lang['sdi']['help_sup1']="Click on validate to definitively delete indicators and associated values (providers, rules and assessment)";
$lang['sdi']['help_sup2']="A warning message will appear if the theme is empty after the indicator deletion";
?>
